package model

import (
	"time"

	"go.mongodb.org/mongo-driver/bson/primitive"
)

// 模型库
type HubMesh struct {
	Id         primitive.ObjectID `bson:"_id,omitempty" json:"_id"`
	UserId     primitive.ObjectID `bson:"userId,omitempty" json:"userId"`
	Name       string             `bson:"name,omitempty" json:"name"`
	Thumbnail  string             `bson:"thumbnail,omitempty" json:"thumbnail"`
	Host       string             `bson:"host,omitempty" json:"host"`
	DbId       string             `bson:"dbid,omitempty" json:"dbid"`
	DbName     string             `bson:"dbName,omitempty" json:"dbName"`
	DefineId   string             `bson:"defineId,omitempty" json:"defineId"`
	Collection string             `bson:"collection,omitempty" json:"collection"`

	CreateTime time.Time `bson:"createTime,omitempty" json:"createTime"`
}

type Mesh struct {
	Id         primitive.ObjectID `bson:"_id,omitempty" json:"_id"`
	CreateTime time.Time          `bson:"createTime,omitempty" json:"createTime"`
	Name       string             `bson:"name,omitempty" json:"name"`
	Category   string             `bson:"category,omitempty" json:"category"`
	Thumbnail  *OssType           `bson:"thumbnail,omitempty" json:"thumbnail"`

	Osgjsbin  *OssType `bson:"osgjsbin,omitempty" json:"osgjsbin"`
	Osgjs     *OssType `bson:"osgjs,omitempty" json:"osgjs"`
	Materials *[]struct {
		Name string     `bson:"name" json:"name"`
		Data *MatConfig `bson:"data" json:"data"`
	} `bson:"materials,omitempty" json:"materials"`
	Geometries []string `bson:"geometries,omitempty" json:"geometries"`
	File       *OssType `bson:"file,omitempty" json:"file"`
	Shadow     *OssType `bson:"shadow,omitempty" json:"shadow,omitempty"`
	MeshState  *int32   `bson:"meshState,omitempty" json:"meshState,omitempty"`
}

type ShoeCompDef struct {
	Node   string `bson:"node,omitempty" json:"node"`
	MatId  int32  `bson:"matId,omitempty" json:"matId"`
	Name   string `bson:"name,omitempty" json:"name"`
	Enable bool   `bson:"enable,omitempty" json:"enable"`
}

type ShoeMesh struct {
	Id     primitive.ObjectID `bson:"_id,omitempty" json:"_id,omitempty"`
	UserId primitive.ObjectID `bson:"userId,omitempty" json:"userId,omitempty"`
	MeshId primitive.ObjectID `bson:"meshId,omitempty" json:"meshId,omitempty"`

	Thumbnail      *OssType       `bson:"thumbnail,omitempty" json:"thumbnail,omitempty"`
	Name           string         `bson:"name,omitempty" json:"name,omitempty"`
	CreateTime     time.Time      `bson:"createTime,omitempty" json:"createTime,omitempty"`
	LeftComponents []*ShoeCompDef `bson:"leftComponents,omitempty" json:"leftComponents,omitempty"`

	Sex    uint8  `bson:"sex,omitempty" json:"sex,omitempty"`
	Season uint8  `bson:"season,omitempty" json:"season,omitempty"`
	Type   string `bson:"type,omitempty" json:"type,omitempty"`

	IsPublic *bool `bson:"isPublic,omitempty" json:"isPublic,omitempty"`
	Platform *bool `bson:"platform,omitempty" json:"platform,omitempty"` //是否属于平台
}

type LastMesh struct {
	Id     primitive.ObjectID `bson:"_id,omitempty" json:"_id,omitempty"`
	UserId primitive.ObjectID `bson:"userId,omitempty" json:"userId,omitempty"`
	MeshId primitive.ObjectID `bson:"meshId,omitempty" json:"meshId,omitempty"`

	Thumbnail  *OssType  `bson:"thumbnail,omitempty" json:"thumbnail,omitempty"`
	Name       string    `bson:"name,omitempty" json:"name,omitempty"`
	CreateTime time.Time `bson:"createTime,omitempty" json:"createTime,omitempty"`

	Sex    uint8  `bson:"sex,omitempty" json:"sex,omitempty"`
	Season uint8  `bson:"season,omitempty" json:"season,omitempty"`
	Type   string `bson:"type,omitempty" json:"type,omitempty"`

	IsPublic   *bool    `bson:"isPublic,omitempty" json:"isPublic,omitempty"`
	Platform   *bool    `bson:"platform,omitempty" json:"platform,omitempty"` //是否属于平台
	State      int32    `bson:"state,omitempty" json:"state"`
	Categories []string `bson:"categories,omitempty" json:"categories,omitempty"` //所有一级分类的id数组 contain filter里面的值
	MeshState  *int32   `bson:"meshState,omitempty" json:"meshState,omitempty"`
}

type HeelMesh struct {
	Id     primitive.ObjectID `bson:"_id,omitempty" json:"_id,omitempty"`
	UserId primitive.ObjectID `bson:"userId,omitempty" json:"userId,omitempty"`
	MeshId primitive.ObjectID `bson:"meshId,omitempty" json:"meshId,omitempty"`

	Thumbnail  *OssType  `bson:"thumbnail,omitempty" json:"thumbnail,omitempty"`
	Name       string    `bson:"name,omitempty" json:"name,omitempty"`
	CreateTime time.Time `bson:"createTime,omitempty" json:"createTime,omitempty"`

	Sex    uint8  `bson:"sex,omitempty" json:"sex,omitempty"`
	Season uint8  `bson:"season,omitempty" json:"season,omitempty"`
	Type   string `bson:"type,omitempty" json:"type,omitempty"`

	IsPublic   *bool    `bson:"isPublic,omitempty" json:"isPublic,omitempty"`
	Platform   *bool    `bson:"platform,omitempty" json:"platform,omitempty"` //是否属于平台
	State      int32    `bson:"state,omitempty" json:"state"`
	Categories []string `bson:"categories,omitempty" json:"categories,omitempty"` //所有一级分类的id数组 contain filter里面的值
	MeshState  *int32   `bson:"meshState,omitempty" json:"meshState,omitempty"`
}

type DecorateMesh struct {
	Id     primitive.ObjectID `bson:"_id,omitempty" json:"_id,omitempty"`
	UserId primitive.ObjectID `bson:"userId,omitempty" json:"userId,omitempty"`
	MeshId primitive.ObjectID `bson:"meshId,omitempty" json:"meshId,omitempty"`

	Thumbnail  *OssType  `bson:"thumbnail,omitempty" json:"thumbnail,omitempty"`
	Name       string    `bson:"name,omitempty" json:"name,omitempty"`
	CreateTime time.Time `bson:"createTime,omitempty" json:"createTime,omitempty"`

	Sex    uint8  `bson:"sex,omitempty" json:"sex,omitempty"`
	Season uint8  `bson:"season,omitempty" json:"season,omitempty"`
	Type   string `bson:"type,omitempty" json:"type,omitempty"`

	IsPublic   *bool    `bson:"isPublic,omitempty" json:"isPublic,omitempty"`
	Platform   *bool    `bson:"platform,omitempty" json:"platform,omitempty"` //是否属于平台
	State      int32    `bson:"state,omitempty" json:"state"`
	Categories []string `bson:"categories,omitempty" json:"categories,omitempty"` //所有一级分类的id数组 contain filter里面的值
	MeshState  *int32   `bson:"meshState,omitempty" json:"meshState,omitempty"`
}

type SoleMesh struct {
	Id     primitive.ObjectID `bson:"_id,omitempty" json:"_id,omitempty"`
	UserId primitive.ObjectID `bson:"userId,omitempty" json:"userId,omitempty"`
	MeshId primitive.ObjectID `bson:"meshId,omitempty" json:"meshId,omitempty"`

	Thumbnail  *OssType  `bson:"thumbnail,omitempty" json:"thumbnail,omitempty"`
	Name       string    `bson:"name,omitempty" json:"name,omitempty"`
	CreateTime time.Time `bson:"createTime,omitempty" json:"createTime,omitempty"`

	Sex    uint8  `bson:"sex,omitempty" json:"sex,omitempty"`
	Season uint8  `bson:"season,omitempty" json:"season,omitempty"`
	Type   string `bson:"type,omitempty" json:"type,omitempty"`

	IsPublic   *bool    `bson:"isPublic,omitempty" json:"isPublic,omitempty"`
	Platform   *bool    `bson:"platform,omitempty" json:"platform,omitempty"` //是否属于平台
	State      int32    `bson:"state,omitempty" json:"state"`
	Categories []string `bson:"categories,omitempty" json:"categories,omitempty"` //所有一级分类的id数组 contain filter里面的值
	MeshState  *int32   `bson:"meshState,omitempty" json:"meshState,omitempty"`
}

type StickerImage struct {
	Id         primitive.ObjectID `bson:"_id,omitempty" json:"_id,omitempty"`
	UserId     primitive.ObjectID `bson:"userId,omitempty" json:"userId,omitempty"`
	Image      *OssType           `bson:"image,omitempty" json:"image,omitempty"`
	Name       string             `bson:"name,omitempty" json:"name,omitempty"`
	CreateTime time.Time          `bson:"createTime,omitempty" json:"createTime,omitempty"`
	State      int32              `bson:"state,omitempty" json:"state"`
	Categories []string           `bson:"categories,omitempty" json:"categories,omitempty"` //所有一级分类的id数组 contain filter里面的值
}
